@@ -3,5 +3,5 @@ from django.apps import AppConfig
 
 class DictionaryConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
-    name = 'sky_dictionary'
-    verbose_name = u'字典模块'
+    name = 'apps.dictionary'
+    verbose_name = u'配置模块'
